@@ -3,7 +3,7 @@
 ** Copyright (C) 2015 The Qt Company Ltd.
 ** Contact: http://www.qt.io/licensing
 **
-** This file is part of the Qt Build Suite.
+** This file is part of Qbs.
 **
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
@@ -72,6 +72,7 @@
 #include <QMutexLocker>
 #include <QRegExp>
 #include <QSharedData>
+#include <QtDebug>
 
 namespace qbs {
 namespace Internal {
@@ -236,6 +237,7 @@ GroupData ProjectPrivate::createGroupDataFromGroup(const GroupPtr &resolvedGroup
 {
     GroupData group;
     group.d->name = resolvedGroup->name;
+    group.d->prefix = resolvedGroup->prefix;
     group.d->location = resolvedGroup->location;
     foreach (const SourceArtifactConstPtr &sa, resolvedGroup->files)
         group.d->sourceArtifacts << createApiSourceArtifact(sa);
@@ -659,6 +661,7 @@ RuleCommandList ProjectPrivate::ruleCommands(const ProductData &product,
                 foreach (const AbstractCommandPtr &internalCommand, transformer->commands) {
                     RuleCommand externalCommand;
                     externalCommand.d->description = internalCommand->description();
+                    externalCommand.d->extendedDescription = internalCommand->extendedDescription();
                     switch (internalCommand->type()) {
                     case AbstractCommand::JavaScriptCommandType: {
                         externalCommand.d->type = RuleCommand::JavaScriptCommandType;
@@ -1008,16 +1011,20 @@ QList<InstallableFile> Project::installableFilesForProduct(const ProductData &pr
     foreach (const GroupConstPtr &group, internalProduct->groups) {
         foreach (const SourceArtifactConstPtr &artifact, group->allFiles()) {
             InstallableFile f;
-            const QString &targetFilePath = ProductInstaller::targetFilePath(internalProduct->topLevelProject(),
+            try {
+                const QString &targetFilePath = ProductInstaller::targetFilePath(internalProduct->topLevelProject(),
                     internalProduct->sourceDirectory,
                     artifact->absoluteFilePath, artifact->properties, mutableOptions);
-            if (targetFilePath.isEmpty())
-                continue;
-            f.d->sourceFilePath = artifact->absoluteFilePath;
-            f.d->fileTags = artifact->fileTags.toStringList();
-            f.d->targetFilePath = targetFilePath;
-            f.d->isValid = true;
-            installableFiles << f;
+                if (targetFilePath.isEmpty())
+                    continue;
+                f.d->sourceFilePath = artifact->absoluteFilePath;
+                f.d->fileTags = artifact->fileTags.toStringList();
+                f.d->targetFilePath = targetFilePath;
+                f.d->isValid = true;
+                installableFiles << f;
+            } catch (const ErrorInfo &e) {
+                qDebug() << e.toString();
+            }
         }
     }
     if (internalProduct->enabled) {
@@ -1026,17 +1033,21 @@ QList<InstallableFile> Project::installableFilesForProduct(const ProductData &pr
                  ArtifactSet::fromNodeSet(internalProduct->buildData->nodes)) {
             if (artifact->artifactType == Artifact::SourceFile)
                 continue;
-            InstallableFile f;
-            const QString &targetFilePath = ProductInstaller::targetFilePath(internalProduct->topLevelProject(),
-                    internalProduct->sourceDirectory,
-                    artifact->filePath(), artifact->properties, mutableOptions);
-            if (targetFilePath.isEmpty())
-                continue;
-            f.d->sourceFilePath = artifact->filePath();
-            f.d->fileTags = artifact->fileTags().toStringList();
-            f.d->targetFilePath = targetFilePath;
-            f.d->isValid = true;
-            installableFiles << f;
+            try {
+                InstallableFile f;
+                const QString &targetFilePath = ProductInstaller::targetFilePath(internalProduct->topLevelProject(),
+                        internalProduct->sourceDirectory, artifact->filePath(),
+                        artifact->properties, mutableOptions);
+                if (targetFilePath.isEmpty())
+                    continue;
+                f.d->sourceFilePath = artifact->filePath();
+                f.d->fileTags = artifact->fileTags().toStringList();
+                f.d->targetFilePath = targetFilePath;
+                f.d->isValid = true;
+                installableFiles << f;
+            } catch (const ErrorInfo &e) {
+                qDebug() << e.toString();
+            }
         }
     }
     qSort(installableFiles);
@@ -1072,18 +1083,17 @@ void Project::updateTimestamps(const QList<ProductData> &products)
 
 /*!
  * \brief Finds files generated from the given file in the given product.
- * The function returns files generated from the given file and the given product. To do so it will
- * traverse the graph of generated files and the files generated from those files.
- *
- * If an empty list of tags is given, then all directly and indirectly generated files will be
- * returned. If there are tags, then processing will stop once matching files were found.
+ * If \a recursive is \c false, only files generated directly from \a file will be considered,
+ * otherwise the generated files are collected recursively.
+ * If \a tags is not empty, only generated files matching at least one of these tags will
+ * be considered.
  */
 QStringList Project::generatedFiles(const ProductData &product, const QString &file,
-                                    const QStringList &tags) const
+                                    bool recursive, const QStringList &tags) const
 {
     QBS_ASSERT(isValid(), return QStringList());
     const ResolvedProductConstPtr internalProduct = d->internalProduct(product);
-    return internalProduct->generatedFiles(file, FileTags::fromStringList(tags));
+    return internalProduct->generatedFiles(file, recursive, FileTags::fromStringList(tags));
 }
 
 QVariantMap Project::projectConfiguration() const
